@@ -11,8 +11,8 @@
 #define XTENSOR_CONFIG_HPP
 
 #define XTENSOR_VERSION_MAJOR 0
-#define XTENSOR_VERSION_MINOR 23
-#define XTENSOR_VERSION_PATCH 8
+#define XTENSOR_VERSION_MINOR 24
+#define XTENSOR_VERSION_PATCH 1
 
 
 // Define if the library is going to be using exceptions.
@@ -57,6 +57,12 @@
     xt::svector<typename XTENSOR_DEFAULT_DATA_CONTAINER(T, EA)::size_type, 4, SA, true>
 #endif
 
+#ifdef XTENSOR_USE_XSIMD
+    #include <xsimd/xsimd.hpp>
+    #define XSIMD_DEFAULT_ALIGNMENT xsimd::default_arch::alignment()
+#endif
+
+
 #ifndef XTENSOR_DEFAULT_ALLOCATOR
 #ifdef XTENSOR_ALLOC_TRACKING
     #ifndef XTENSOR_ALLOC_TRACKING_POLICY
@@ -72,7 +78,7 @@
     #endif
 #else
     #ifdef XTENSOR_USE_XSIMD
-        #include <xsimd/xsimd.hpp>
+        
         #define XTENSOR_DEFAULT_ALLOCATOR(T) \
             xsimd::aligned_allocator<T, XSIMD_DEFAULT_ALIGNMENT>
     #else
@@ -102,6 +108,10 @@
 #define XTENSOR_OPENMP_TRESHOLD 0
 #endif
 
+#ifndef XTENSOR_TBB_THRESHOLD
+#define XTENSOR_TBB_THRESHOLD 0
+#endif
+
 #ifndef XTENSOR_SELECT_ALIGN
 #define XTENSOR_SELECT_ALIGN(T) (XTENSOR_DEFAULT_ALIGNMENT != 0 ? XTENSOR_DEFAULT_ALIGNMENT : alignof(T))
 #endif
